@@ -46,9 +46,9 @@ details on the use of this package.
 """
 
 __copyright__ = 'Copyright (C) 2020, 2021 Serghei Iakovlev'
-__version__ = '0.4.0'
+__version__ = '0.5.0'
 __license__ = 'GPLv3+'
 __author__ = 'Serghei Iakovlev'
 __author_email__ = 'egrep@protonmail.ch'
 __url__ = 'https://gstore.readthedocs.io'
-__description__ = 'Synchronize GitHub repositories made easy'
+__description__ = 'Synchronize GitHub repositories made easy.'
